@@ -1,28 +1,9 @@
-import attr
 from typing import Any, List, Optional
-from dapodik import (
-    DapodikObject,
-    PesertaDidikBaru,
-    Sekolah,
-    Agama,
-    KebutuhanKhusus,
-    JenisTinggal,
-    AlatTransportasi,
-)
-from dapodik.utils.decorator import set_meta
+from dapodik.base import dataclass, field
 
 
-@set_meta(
-    "peserta_didik_id",
-    sekolah=Sekolah,
-    pdb=PesertaDidikBaru,
-    agama=Agama,
-    kebutuhan_khusus=KebutuhanKhusus,
-    jenis_tinggal=JenisTinggal,
-    alat_transportasi=AlatTransportasi,
-)
-@attr.dataclass
-class PesertaDidik(DapodikObject):
+@dataclass
+class PesertaDidik:
     nama: str
     jenis_kelamin: str
     tempat_lahir: str
@@ -105,12 +86,6 @@ class PesertaDidik(DapodikObject):
     nomor_telepon_rumah: str = ""
     nomor_telepon_seluler: str = ""
     email: str = ""
-    kebutuhan_khusus_id_selector: List[Any] = attr.Factory(list)
-    kebutuhan_khusus_id_selector_ayah: List[Any] = attr.Factory(list)
-    kebutuhan_khusus_id_selector_ibu: List[Any] = attr.Factory(list)
-
-    @property
-    def params(self):
-        return {
-            "sekolah_id": self.dapodik.sekolah_id,
-        }
+    kebutuhan_khusus_id_selector: List[Any] = field(factory=list)
+    kebutuhan_khusus_id_selector_ayah: List[Any] = field(factory=list)
+    kebutuhan_khusus_id_selector_ibu: List[Any] = field(factory=list)
