@@ -1,15 +1,10 @@
-import attr
-from dapodik import DapodikObject, PesertaDidik, Semester
-from dapodik.utils.decorator import set_meta
+from dapodik.base import dataclass
 
 DEF = "Admin.model.PesertaDidikLongitudinal-1"
 
 
-@set_meta(
-    "peserta_didik_longitudinal_id", peserta_didik=PesertaDidik, semester=Semester
-)
-@attr.dataclass
-class PesertaDidikLongitudinal(DapodikObject):
+@dataclass
+class PesertaDidikLongitudinal:
     peserta_didik_id: int
     tinggi_badan: int
     berat_badan: int
