@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("agama_id")
-@attr.dataclass(frozen=True)
-class Agama(DapodikObject):
+@dataclass(frozen=True)
+class Agama:
     agama_id: int
     nama: str
     create_date: datetime
