@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("akses_internet_id")
-@attr.dataclass(frozen=True)
-class AksesInternet(DapodikObject):
+@dataclass(frozen=True)
+class AksesInternet:
     akses_internet_id: int
     nama: str
     media: str
