@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("alat_transportasi_id")
-@attr.dataclass(frozen=True)
-class AlatTransportasi(DapodikObject):
+@dataclass(frozen=True)
+class AlatTransportasi:
     alat_transportasi_id: str
     nama: str
     create_date: datetime
