@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("bentuk_lembaga_id")
-@attr.dataclass(frozen=True)
-class BentukLembaga(DapodikObject):
+@dataclass(frozen=True)
+class BentukLembaga:
     bentuk_lembaga_id: str
     nama: str
     create_date: datetime
