@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("id_biblio")
-@attr.dataclass(frozen=True)
-class Biblio(DapodikObject):
+@dataclass(frozen=True)
+class Biblio:
     id_biblio: str
     id_freq: Optional[str]
     id_publisher: str
