@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("id_gmd")
-@attr.dataclass(frozen=True)
-class Gmd(DapodikObject):
+@dataclass(frozen=True)
+class Gmd:
     id_gmd: str
     nm_gmd: str
     create_date: datetime
