@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("jenis_gugus_id")
-@attr.dataclass(frozen=True)
-class JenisGugus(DapodikObject):
+@dataclass(frozen=True)
+class JenisGugus:
     jenis_gugus_id: str
     jenis_gugus: str
     create_date: datetime
