@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("id_hapus_buku")
-@attr.dataclass(frozen=True)
-class JenisHapusBuku(DapodikObject):
+@dataclass(frozen=True)
+class JenisHapusBuku:
     id_hapus_buku: str
     ket_hapus_buku: str
     u_prasarana: str
