@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("jenis_keluar_id")
-@attr.dataclass(frozen=True)
-class JenisKeluar(DapodikObject):
+@dataclass(frozen=True)
+class JenisKeluar:
     jenis_keluar_id: str
     ket_keluar: str
     keluar_pd: str
