@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("jenis_pendaftaran_id")
-@attr.dataclass(frozen=True)
-class JenisPendaftaran(DapodikObject):
+@dataclass(frozen=True)
+class JenisPendaftaran:
     jenis_pendaftaran_id: str
     nama: str
     daftar_sekolah: str
