@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("jenis_prasarana_id")
-@attr.dataclass(frozen=True)
-class JenisPrasarana(DapodikObject):
+@dataclass(frozen=True)
+class JenisPrasarana:
     jenis_prasarana_id: int
     nama: str
     a_unit_organisasi: str
