@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("jenis_rombel")
-@attr.dataclass(frozen=True)
-class JenisRombel(DapodikObject):
+@dataclass(frozen=True)
+class JenisRombel:
     jenis_rombel: str
     nm_jenis_rombel: str
     create_date: datetime
