@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("jenis_tinggal_id")
-@attr.dataclass(frozen=True)
-class JenjangPendidikan(DapodikObject):
+@dataclass(frozen=True)
+class JenjangPendidikan:
     jenjang_pendidikan_id: str
     nama: str
     jenjang_lembaga: str
