@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject, JenjangPendidikan
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("jurusan_id", jenjang_pendidikan=JenjangPendidikan)
-@attr.dataclass(frozen=True)
-class Jurusan(DapodikObject):
+@dataclass(frozen=True)
+class Jurusan:
     jurusan_id: str
     nama_jurusan: str
     untuk_sma: str
