@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("pangkat_golongan_id")
-@attr.dataclass(frozen=True)
-class PangkatGolongan(DapodikObject):
+@dataclass(frozen=True)
+class PangkatGolongan:
     pangkat_golongan_id: str
     kode: str
     nama: str
