@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("id_role_pengguna")
-@attr.dataclass(frozen=True)
-class RolePengguna(DapodikObject):
+@dataclass(frozen=True)
+class RolePengguna:
     id_role_pengguna: str
     sekolah_id: str
     lembaga_id: Optional[str]
