@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("status_kepegawaian_id")
-@attr.dataclass(frozen=True)
-class StatusKepegawaian(DapodikObject):
+@dataclass(frozen=True)
+class StatusKepegawaian:
     status_kepegawaian_id: int
     nama: str
     create_date: datetime
