@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("sumber_air_id")
-@attr.dataclass(frozen=True)
-class SumberAir(DapodikObject):
+@dataclass(frozen=True)
+class SumberAir:
     sumber_air_id: str
     nama: str
     sumber_air: str
