@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
-from dapodik import DapodikObject
 from typing import Optional
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("sumber_listrik_id")
-@attr.dataclass(frozen=True)
-class SumberListrik(DapodikObject):
+@dataclass(frozen=True)
+class SumberListrik:
     sumber_listrik_id: str
     nama: str
     create_date: datetime
