@@ -1,14 +1,10 @@
-import attr
 from datetime import datetime, date
-from dapodik import DapodikObject, Sekolah, KebutuhanKhusus, Jurusan
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta(
-    "jurusan_sp_id", sekolah=Sekolah, kebutuhan_khusus=KebutuhanKhusus, jurusan=Jurusan
-)
-@attr.dataclass(frozen=True)
-class JurusanSp(DapodikObject):
+@dataclass(frozen=True)
+class JurusanSp:
     jurusan_sp_id: str
     sekolah_id: str
     kebutuhan_khusus_id: int
